satsim.dataset package — SatSim 0.23.0 documentation

# satsim.dataset package

## Submodules

## satsim.dataset.augment module

satsim.dataset.augment.augment_satnet_with_satsim(dataset, augment_satsim_params, prob=0.5, rn=0, min_snr=2.0, box_pad=10)

  Augments a SatNet Dataset with SatSim images. The SatSim image is added onto the example image. New synthetic targets are appended to the bounding box annotation list.

  Parameters:

    - dataset – tf.Dataset, Dataset object that returns SatNet types: image: tf.float32, bounding box annotations: tf.float32, filename: tf.string, annotation filename : tf.string

    - augment_satsim_params – dict, SatSim simulation parameters

    - prob – float, probability of augmenting the example image. default=0.5

    - rn – float, estimated read noise of sensor in photoelectrons used to estimate SNR. default=0

    - min_snr – float, minimum SNR to include synthetic targets in annotation list. default=2.0

    - box_pad – int, number of pixels to pad synthetic targets on each side. default=10

  Returns:

    A tf.Dataset, the mapped Dataset with SatSim augmentation